.. documentation master file, created by
   sphinx-quickstart on Fri Mar 11 17:22:09 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Standard Evaluator
==================

This project implements the standard evaluator. 

Description
-----------
This project expands the capabilities of the OpenMDAO components. It was developed under NASA Contract 80GRC023CA045.

Dependencies
------------
This project expands on the NASA OpenMDAO package. 

Contents
--------

.. toctree::
   :maxdepth: 2

   theory/index
   demos/index
   reference/index
   notes/index

